==> dneop1_5.0.1.1_pg9.6_linux_x64.tar.gz: dneo/dneores/dneo/lang/en_US/js/vmtg.js <==
if (!desknets.Resource.vmtg) {
    desknets.Resource.vmtg = {};
}
$.extend(desknets.Resource.vmtg, {
    'remainingTimeMessage': '{{remainingTime}} minutes until the meeting ends.',
    'extendableMessage': 'To extend the meeting, click <a href=\'#\' class=\'vmtg-open-extend-dialog\'>here.</a>',
    'failToGetStreamMessage': 'Camera and microphone not recognized. Please check the connections.',
    'failToGetCameraMessage': 'Failed to find a camera. Join the meeting by voice but without video.',
    'failToGetMicMessage': 'Failed to find a microphone. Join the meeting by video but without voice.',
    'failToGetStreamOthersMessage': 'No camera/microphone was found on {{userName}}.',
    'failToGetCameraOthersMessage': 'Mr./Mrs. {{userName}} failed to find a camera.',
    'failToGetMicOthersMessage': 'Mr./Mrs. {{userName}} failed to find a microphone.',
    'changePermission': 'Meeting information has been updated. Click <a href=\'\' onclick=\'location.reload();\'>here</a> to reload.',
    'canNotContinueMeeting': 'You cannot continue the conference because the time of the event has been changed. <br>You will exit in 3 seconds. ',
    'screenSharedDialogTitle': 'Choose a screen to share.',
    'screenShared' : 'Full Screen',
    'windowShared' : 'Window',
    'screenNotAllowed': 'W:You have no permission to share a screen.',
    'extensionRequiredError': 'W:Cannnot start screen sharing. <br>Please refer to the following URL and allow screen sharing.',
    'extendDialogTitle': 'Extend Meeting',
    'screenAssignDialogTitle': 'Show on Screen',
    'screenManageDialogTitle': 'Choose Layout',
    'extendLabel' : 'Extend',
    'outofdateDialog': 'Cannot connect to the real-time server since it is outside of the reservation period.',
    'notAllowedDialog': 'You are not allowed to access the meeting.',
    'authWebhookFailure': 'W:Failed to connect. There may be a problem with the configuration of the Webhook authentication. <br/>Ask your system administrator.',
    'messageNewArrival': 'You have received new message(s).',
    'messageSend': 'The message has been sent.',
    'changedLayoutByOther': 'Another person in charge has changed the layout.',
    'confirmToExit': 'Are you sure you want to exit?',
    'confirmToEndMeeting': 'Meeting will be closed. Are you sure you want to continue?',
    'assignDialogTargetUser': 'Target User',
    'canNotExtendMeeting': 'Cannnot extend the meeting because the facility may already have been reserved by another user or changing the time for the facility is not allowed.',
    'unselected': 'Unselected',
    'unknownDevice': 'Unknown device'
});

==> dneop2_5.5.1.2_pg9.6_linux_x64.tar.gz: dneo/dneores/dneo/lang/en_US/js/vmtg.js <==
if (!desknets.Resource.vmtg) {
    desknets.Resource.vmtg = {};
}
$.extend(desknets.Resource.vmtg, {
    'remainingTimeMessage': '{{remainingTime}} minutes until the meeting ends.',
    'extendableMessage': 'To extend the meeting, click <a href=\'#\' class=\'vmtg-open-extend-dialog\'>here.</a>',
    'failToGetStreamMessage': 'Camera and microphone not recognized. Please check the connections.',
    'failToGetCameraMessage': 'Failed to find a camera. Join the meeting by voice but without video.',
    'failToGetMicMessage': 'Failed to find a microphone. Join the meeting by video but without voice.',
    'failToGetStreamOthersMessage': 'No camera/microphone was found on {{userName}}.',
    'failToGetCameraOthersMessage': 'Mr./Mrs. {{userName}} failed to find a camera.',
    'failToGetMicOthersMessage': 'Mr./Mrs. {{userName}} failed to find a microphone.',
    'changePermission': 'Meeting information has been updated. Click <a href=\'\' onclick=\'location.reload();\'>here</a> to reload.',
    'canNotContinueMeeting': 'You cannot continue the conference because the time of the event has been changed. <br>You will exit in 3 seconds. ',
    'screenSharedDialogTitle': 'Choose a screen to share.',
    'screenShared' : 'Full Screen',
    'windowShared' : 'Window',
    'screenNotAllowed': 'W:You have no permission to share a screen.',
    'extensionRequiredError': 'W:Cannnot start screen sharing. <br>Please refer to the following URL and allow screen sharing.',
    'extendDialogTitle': 'Extend Meeting',
    'screenAssignDialogTitle': 'Show on Screen',
    'screenManageDialogTitle': 'Choose Layout',
    'extendLabel' : 'Extend',
    'outofdateDialog': 'Cannot connect to the real-time server since it is outside of the reservation period.',
    'notAllowedDialog': 'You are not allowed to access the meeting.',
    'authWebhookFailure': 'W:Failed to connect. There may be a problem with the configuration of the Webhook authentication. <br/>Ask your system administrator.',
    'messageNewArrival': 'You have received new message(s).',
    'messageSend': 'The message has been sent.',
    'changedLayoutByOther': 'Another person in charge has changed the layout.',
    'confirmToExit': 'Are you sure you want to exit?',
    'confirmToEndMeeting': 'Meeting will be closed. Are you sure you want to continue?',
    'assignDialogTargetUser': 'Target User',
    'canNotExtendMeeting': 'Cannnot extend the meeting because the facility may already have been reserved by another user or changing the time for the facility is not allowed.',
    'unselected': 'Unselected',
    'unknownDevice': 'Unknown device',
    'videoQualitySettingDialogTitle': 'Video Quality Setting',
    'startMeetingDialogTitle': 'Start Meeting',
    'notChairErrorMessage': 'W:Cannnot control the meeting because you are not person-in-charge.'
});
